@@ -7,11 +7,11 @@ import logging
 import time
 import uuid
 
+from google import auth
 from google.api_core import retry
 from google.cloud import pubsub_v1
 
 import octue.exceptions
-from octue.cloud.credentials import GCPCredentialsManager
 from octue.cloud.pub_sub import Subscription, Topic
 from octue.cloud.pub_sub.logging import GooglePubSubHandler
 from octue.cloud.pub_sub.message_handler import OrderedMessageHandler
@@ -59,7 +59,7 @@ class Service(CoolNameable):
 
         self.backend = backend
         self.run_function = run_function
-        self._credentials = GCPCredentialsManager(backend.credentials_environment_variable).get_credentials()
+        self._credentials = auth.default()[0]
         self.publisher = pubsub_v1.PublisherClient(credentials=self._credentials, batch_settings=BATCH_SETTINGS)
         self._current_question = None
         super().__init__(*args, **kwargs)
@@ -75,9 +75,9 @@ class Service(CoolNameable):
         :param bool delete_topic_and_subscription_on_exit: if `True`, delete the service's topic and subscription on exit
         :return None:
         """
-        topic = Topic(name=self.id, namespace=OCTUE_NAMESPACE, service=self)
-        topic.create(allow_existing=True)
+        logger.info("Starting service with ID %r.", self.id)
 
+        topic = Topic(name=self.id, namespace=OCTUE_NAMESPACE, service=self)
         subscriber = pubsub_v1.SubscriberClient(credentials=self._credentials)
 
         subscription = Subscription(
@@ -88,20 +88,31 @@ class Service(CoolNameable):
             subscriber=subscriber,
             expiration_time=None,
         )
-        subscription.create(allow_existing=True)
 
-        future = subscriber.subscribe(subscription=subscription.path, callback=self.answer)
-        logger.debug("%r is waiting for questions.", self)
+        try:
+            topic.create(allow_existing=True)
+            subscription.create(allow_existing=True)
 
-        with subscriber:
-            try:
-                future.result(timeout=timeout)
-            except (TimeoutError, concurrent.futures.TimeoutError, KeyboardInterrupt):
-                future.cancel()
+            future = subscriber.subscribe(subscription=subscription.path, callback=self.answer)
+            logger.debug("%r is waiting for questions.", self)
 
+            with subscriber:
+                try:
+                    future.result(timeout=timeout)
+                except (TimeoutError, concurrent.futures.TimeoutError, KeyboardInterrupt):
+                    future.cancel()
+
+        finally:
             if delete_topic_and_subscription_on_exit:
-                topic.delete()
-                subscription.delete()
+                try:
+                    if subscription.exists():
+                        subscription.delete()
+
+                    if topic.exists():
+                        topic.delete()
+
+                except Exception:
+                    logger.error("Deletion of topic and/or subscription %r failed.", topic.name)
 
     def answer(self, question, answer_topic=None, timeout=30):
         """Answer a question (i.e. run the Service's app to analyse the given data, and return the output values to the
@@ -177,8 +188,8 @@ class Service(CoolNameable):
         input_manifest=None,
         subscribe_to_logs=True,
         allow_local_files=False,
-        timeout=30,
         question_uuid=None,
+        timeout=30,
     ):
         """Ask a serving Service a question (i.e. send it input values for it to run its app on). The input values must
         be in the format specified by the serving Service's Twine file. A single-use topic and subscription are created
@@ -190,8 +201,8 @@ class Service(CoolNameable):
         :param octue.resources.manifest.Manifest|None input_manifest: the input manifest of the question
         :param bool subscribe_to_logs: if `True`, subscribe to logs from the remote service and handle them with the local log handlers
         :param bool allow_local_files: if `True`, allow the input manifest to contain references to local files - this should only be set to `True` if the serving service will have access to these local files
-        :param float|None timeout: time in seconds to keep retrying sending the question
         :param str|None question_uuid: the UUID to use for the question if a specific one is needed; a UUID is generated if not
+        :param float|None timeout: time in seconds to keep retrying sending the question
         :return (octue.cloud.pub_sub.subscription.Subscription, str): the response subscription and question UUID
         """
         if not allow_local_files:
