@@ -5,11 +5,11 @@ import os
 import warnings
 
 import google.api_core.exceptions
+from google import auth
 from google.cloud import storage
 from google.cloud.storage.constants import _DEFAULT_TIMEOUT
 from google_crc32c import Checksum
 
-from octue.cloud.credentials import GCPCredentialsManager
 from octue.cloud.storage.path import split_bucket_name_from_gs_path
 from octue.exceptions import CloudStorageBucketNotFound
 from octue.migrations.cloud_storage import translate_bucket_name_and_path_in_bucket_to_cloud_path
@@ -34,11 +34,10 @@ class GoogleCloudStorageClient:
         warnings.simplefilter("ignore", category=ResourceWarning)
 
         if credentials == OCTUE_MANAGED_CREDENTIALS:
-            credentials = GCPCredentialsManager().get_credentials()
+            credentials, self.project_name = auth.default()
         else:
             credentials = credentials
 
-        self.project_name = credentials.project_id
         self.client = storage.Client(project=self.project_name, credentials=credentials)
 
     def create_bucket(self, name, location=None, allow_existing=False, timeout=_DEFAULT_TIMEOUT):
@@ -58,12 +57,7 @@ class GoogleCloudStorageClient:
 
         self.client.create_bucket(bucket_or_name=name, location=location, timeout=timeout)
 
-    def exists(
-        self,
-        cloud_path=None,
-        bucket_name=None,
-        path_in_bucket=None,
-    ):
+    def exists(self, cloud_path=None, bucket_name=None, path_in_bucket=None):
         """Check if a file exists at the given path.
 
         :param str|None cloud_path: full cloud path to the file (e.g. `gs://bucket_name/path/to/file.csv`)
@@ -164,13 +158,7 @@ class GoogleCloudStorageClient:
             "path_in_bucket": path_in_bucket,
         }
 
-    def overwrite_custom_metadata(
-        self,
-        metadata,
-        cloud_path=None,
-        bucket_name=None,
-        path_in_bucket=None,
-    ):
+    def overwrite_custom_metadata(self, metadata, cloud_path=None, bucket_name=None, path_in_bucket=None):
         """Overwrite the custom metadata for the given cloud file.
 
         :param dict metadata: key-value pairs to set as the new custom metadata
